import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Stack;

/*
This is a Saxon parser. This script will read all the tag and for some of them
made special action
*/
public class Main {
    public static void main(String[] args) {
        try {
            SAXParserFactory factory = SAXParserFactory.newInstance();
            SAXParser saxParser = factory.newSAXParser();

            File file = new File(args[1]);

            if (file.exists()) {
                file.delete();
            }
            file.createNewFile();

            FileWriter fw = new FileWriter(file.getAbsoluteFile());
            final BufferedWriter bw = new BufferedWriter(fw);
           

            DefaultHandler handler;
            handler = new DefaultHandler() {
                
                /* hasMetDiv will count the div */
                int hasMetDiv = 0;

                /* stack on which every element will be put */
                Stack elementStack = new Stack();
                
                /* temporary stack in which we will put element if img,table, .. will be put */
                Stack elementTmpStack = new Stack();
                
                 @Override
                  public void startDocument() { 
                    try {
                        bw.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE html>");
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                 }
                 
                @Override
                public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {
                    try {
                        if(qName == "html"){
                            /* we don't want any attribute in our html tag */
                            bw.write("<html>");  
                        }else 
                            /* if it is not a paragraph inside a paragraph we will open the tag */
                            if(!(qName == "p" && elementStack.peek() == "p")){
                            if((qName == "ul" || qName == "ol" ) && elementStack.peek().toString() == "p"){
                                /* If the father is a paragraph, we close it to open ul/ol tag, we will open it at the end of ul/ol tag*/
                                 bw.write("</p>");    
                            }else if(qName == "div"){
                                hasMetDiv++;
                            }else if(qName == "img"||qName == "audio"||qName == "table"||qName == "video"||qName == "object"){
                                /* We are going to put img/audio/table/.. to the grandfather div 
                                    If there are not descendants of a div tag, we do nothing and it will
                                    be ignore on xslt parsing. Maybe we could do something like putting it on a special div
                                */
                                if(hasMetDiv != 0){
                                  while(!(elementStack.peek().toString() == "div")){ 
                                      /* we close all the father until we met a div, we put all of it on a temporary stack, and we will
                                      re-open it on closing the tag
                                      */
                                        bw.write("</" + elementStack.peek().toString() + ">");
                                        elementTmpStack.push(elementStack.pop());
                                    }
                                }     
                            }
                            /* we write the tag */
                            bw.write("<" + qName);
                            for(int i = 0; i<attributes.getLength(); i++) {
                                bw.write(" "+attributes.getQName(i)+"=\""+attributes.getValue(i)+"\"");
                            }
                            bw.write(">");     
                        }
                        /* we push the tag on the stack */
                        elementStack.push(qName);
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }

                @Override
                public void endElement(String uri, String localName, String qName) throws SAXException {
                    try {
                        /* we pop the tag from the stack */
                        elementStack.pop();
                        
                        /* if it is not a paragraph inside a paragraph we close the tag */
                       if(!(qName == "p" && elementStack.peek() == "p")){
                            bw.write("</" + qName + ">");
                            if((qName == "ul" || qName == "ol") && (elementStack.peek() == "p")){
                                 bw.write("<p>");
                            }else if(qName == "div"){
                                hasMetDiv--;
                            }else if(qName == "img"||qName == "audio"||qName == "table"||qName == "video"||qName == "object"){
                              if(hasMetDiv != 0){
                                while(!elementTmpStack.isEmpty()){
                                    /* 
                                    we re-open all the tags that we close on opening img/audio/table/ ...
                                    */
                                    bw.write("<" + elementTmpStack.peek() + ">");
                                    elementStack.push(elementTmpStack.pop());
                                }   
                                elementTmpStack.clear();
                              }
                            }     
                        }
                  }catch (IOException e) {
                        e.printStackTrace();
                    }
                }

                @Override
                public void characters(char ch[], int start, int length) throws SAXException {
                    try {
                        bw.write(new String(ch, start, length));
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }

            };
            saxParser.parse(args[0], handler);

            bw.close();

        } catch (ParserConfigurationException e) {
            e.printStackTrace();
        } catch (SAXException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }


    }
}
