<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    exclude-result-prefixes="xs"
    version="2.0">   
    <xsl:output method="xml" indent="yes"/>

    <xsl:template match="html">
        <!--<xsl:processing-instruction name="oxygen">
            RNGSchema="http://scenari.utc.fr/hdoc/schemas/xhtml/hdoc1-xhtml.rng" type="xml"
        </xsl:processing-instruction>-->
        <html xmlns="http://www.utc.fr/ics/hdoc/xhtml">
            
            <xsl:apply-templates select="head"/>
            <xsl:apply-templates select="body"/>
            
        </html>
    </xsl:template>
    <!-- Head -->
    <xsl:template match="head">
        <head>
            <title><xsl:value-of select="title"/></title>
            <meta charset="utf-8"/>
            <meta generator="SimpleChain"/>
            <xsl:apply-templates select="meta[@name]"/>
        </head>
    </xsl:template>
    <xsl:template match="meta[@name='author']|meta[@name='description']|meta[@name='keywords']">
        <meta name="{@name}" content="{@content}" />
    </xsl:template>
    
    <!-- BODY -->
    <xsl:template match="body">
        <body>
            <xsl:apply-templates select="div"/>
        </body>
    </xsl:template>
    
    <!-- //body/div -->
    <xsl:template match="//body/div">
        <xsl:if test="string(.)">
            <section>
                <header>
                    <h1><xsl:value-of select="h1[1]"/></h1>
                </header>
                <xsl:apply-templates select='div'/>
            </section>
        </xsl:if>
    </xsl:template>
    <!-- //body/div/ -->
    
    <!-- //body/div/ -->
    
    
    <xsl:template match="//body/div/text()">
        <xsl:if test="normalize-space(.) != ''">
            <div>
                <p><xsl:value-of select="."/></p>
            </div>
        </xsl:if>
    </xsl:template>
    

    
    <xsl:template match="p">
        <xsl:if test="normalize-space(.) != ''">
            <xsl:choose>
                <xsl:when test="ancestor::p">
                     <xsl:apply-templates/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:choose>
                        <xsl:when test="ancestor::li">
                            <p><xsl:apply-templates/></p>
                        </xsl:when>
                        <xsl:otherwise>
                             <p><xsl:apply-templates/></p>
                        </xsl:otherwise>
                    </xsl:choose>
               </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    

    
    <xsl:template match="//body/div/div">
        <xsl:if test="normalize-space(.) != ''">
            <xsl:if test="descendant::p|descendant::ul|descendant::ol|descendant::img|descendant::audio|descendant::video|descendant::table|descendant::object">
            <div>
                <xsl:apply-templates select="p|ul|ol|img|div|audio|video|object|table"/>
            </div>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="div">
        <xsl:if test="normalize-space(.) != ''">
            <xsl:if test="descendant::p|descendant::ul|descendant::ol|descendant::img|descendant::audio|descendant::video|descendant::table|descendant::object">
                    <xsl:apply-templates select="p|ul|ol|img|div|audio|video|object|table"/>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    
    <!-- //body/div/div -->
      
    <xsl:template match="//body/div/div/ul|//body/div/div/ol">
        <xsl:if test="normalize-space(.) != ''">
            <xsl:copy>
                <xsl:apply-templates/>
            </xsl:copy>
        </xsl:if>
    </xsl:template>
    
    
    <xsl:template match="//body/div/div/text()">
        <xsl:if test="normalize-space(.) != ''">
            <p>
                <xsl:value-of select="."/>
            </p>
        </xsl:if>
    </xsl:template>
    
   <xsl:template match="ul|ol">
        <xsl:if test="normalize-space(.) != ''">
            <xsl:copy><xsl:apply-templates select="li"/></xsl:copy>
        </xsl:if>
        </xsl:template>
        
    <xsl:template match="ul/li|ol/li">
        <xsl:if test="normalize-space(.) != ''">      
        
            <xsl:choose>
                <xsl:when test="p|ul|ol">
                    <xsl:if test="normalize-space(.) != ''">    
                    <li>
                        <xsl:apply-templates select="p|ul|ol"/>
                    </li>
                    </xsl:if>
                </xsl:when>
                <xsl:otherwise>
                    <li>
                    <p><xsl:apply-templates/></p>
                    </li>
                </xsl:otherwise>
           </xsl:choose>
        
        </xsl:if>
    </xsl:template>
    <xsl:template match="table">
        <table>
            <xsl:apply-templates select="caption"/>
            <xsl:apply-templates select="tbody"/>
        </table>
    </xsl:template>
    <xsl:template match="tbody">
        <xsl:apply-templates select="tr"/>
    </xsl:template>
    
    <xsl:template match="caption">
        <caption>
            <xsl:value-of select="."/>
        </caption>
    </xsl:template>
    
    <xsl:template match="tr">
        <tr>
            <xsl:apply-templates select="td|th"/>
        </tr>
    </xsl:template>
    <xsl:template match="td|th">
        <td>
            <xsl:apply-templates select="text()|ul|ol|p|div"/>
        </td>
    </xsl:template>
    <xsl:template match="div/td|div/th">
        <td>
            <p>
                <xsl:apply-templates select="text()|ul|ol|p|div"/> 
            </p>
        </td>
    </xsl:template>
    <xsl:template match="td/text()|th/text()">
        <p>
            <xsl:value-of select='.'/>
        </p>
    </xsl:template>
    <xsl:template match="img">
        <img src="{@src}" alt="{@alt}"/>
    </xsl:template>
    
    <xsl:template match="object">
        <object type="{@type}" data="{@data}"/>
    </xsl:template>

    
    <xsl:template match="audio">
        <audio src="{@src}"/>
    </xsl:template>
    <xsl:template match="video[not(@type)]">
        <video src="{@src}" type="video/webm"/>
    </xsl:template>
    <xsl:template match="video">
        <xsl:choose>
            <xsl:when test="@type != 'video/mp4'  or @type != 'video/ogg' or @type != 'video/webm'">
                <video src="{@src}" type="video/webm"/>
            </xsl:when>
            <xsl:otherwise>
                <video src="{@src}" type="{@type}"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    
    <xsl:template match="em">
        <xsl:copy><xsl:apply-templates/></xsl:copy>
    </xsl:template>
    <xsl:template match="i">
        <xsl:copy><xsl:apply-templates/></xsl:copy>
    </xsl:template>
    <xsl:template match="a">
        <a href="{@href}"><xsl:apply-templates/></a>
    </xsl:template>
  
    <xsl:template match="span">
        <span><xsl:apply-templates/></span>
    </xsl:template>
    

    <!--<xsl:template match="h1|h2|h3|h4|h5|h6">
        <h6><xsl:value-of select="."/></h6>
        </xsl:template>   --> 
</xsl:stylesheet>

