import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;


public class convertMedia {

	/**
	 * @param args
	 * @throws IOException 
	 * @throws ParseException 
	 */
	public static void main(String[] args) throws IOException, ParseException {
		// TODO Auto-generated method stub
		BufferedReader source = null;
		BufferedWriter tempFile = null;
		String line;
		
		//We catch the input and output file from the program arguments 
		if(args.length>=2){
			source = new BufferedReader(new FileReader(args[0]));
			tempFile = new BufferedWriter(new FileWriter(args[1]));
		}
		else throw new IllegalArgumentException();
		
		/*We read each line of the xml file:
		 * if it's a date we convert it to the ISO date format
		 * if it contains shortcodes ( [video] and [audio] in this case we convert it to the
		 * appropriate hdoc tag (<video> and <audio>)
		 */
		while((line = source.readLine()) != null){
			if(isTag("pubDate", line)){
				String newDate = convertToDate(line);
				line = replaceDate(line, newDate);
			}
			line = replaceShortcodes(line);
			tempFile.append(line+"\n");
		}
		
		source.close();
		tempFile.close();
		
	}
	
	/*Function that returns true if the line contains the tag given in the argument
	 */
	private static boolean isTag(String tag, String line){
		if(line.matches(".*<"+tag+".*\\>.*\\</"+tag+">.*"))
			return true;
		return false;
	}
	
	/*Function that convert the WordPress date to the ISO Date format*/
	private static String convertToDate(String line) throws ParseException{
		int begin = line.indexOf("<pubDate>")+ ("<pubDate>").length();
		int end = line.indexOf("</pubDate>")  ;
		String str = line.substring(begin, end);
		Date date = new SimpleDateFormat("EEE, d MMM yyyy HH:mm:ss Z", Locale.ENGLISH).parse(str);
		SimpleDateFormat convertedDate = new SimpleDateFormat("yyyy-MM-dd");
		return convertedDate.format(date);
	}
	
	/*Function that replace the old date by the new one (the ISO Date)*/
	private static String replaceDate(String line, String newDate){
		int begin = line.indexOf("<pubDate>")+ ("<pubDate>").length();
		int end = line.indexOf("</pubDate>") ;
		StringBuilder str = new StringBuilder(line);
		return str.replace(begin, end, newDate).toString();
	}
	
	/*Function that convert the shortcodes to the appropriate hdoc tags
	 * The function doesn't support the case where the shortcodes are split in many lines.
	 * The function support the case where there is more than one shortcode in one line*/
	private static String replaceShortcodes(String line){
		/*We suppose that the shortcode can't be split in many lines*/
		String att = "";
		String shortcode = "";
		
		if(containsShortcode("audio", line)){
			shortcode = "audio";
			att = "mp3";
		}
		else if(containsShortcode("video", line)){
			shortcode ="video";
			att = "mp4";
		}
		else return line;

		String src = getAttributeValue(att, line);
		String hdocCode = "";
		if(shortcode == "video")
			hdocCode = "<"+shortcode+" type=\"video/mp4\" src=\""+src+"\"></"+shortcode+">";
		else hdocCode = "<"+shortcode+" src=\""+src+"\"></"+shortcode+">";
		line = replaceShortcode(line, shortcode, hdocCode);
		return replaceShortcodes(line);
	}
	/*Function that return true if the line contains the shortcode given as argument*/
	private static boolean containsShortcode(String shortcode, String str){
		if(str.matches(".*\\["+shortcode+".*\\].*\\[/"+shortcode+"].*"))
			return true;
		return false;
	}
	
	/*Function that return the value of the attribute given as argument*/
	private static String getAttributeValue(String attribute, String str){	
		int attValueIndexBegin = str.indexOf("\"", str.indexOf(attribute+"=\"")) + 1;
		int attValueIndexEnd = str.indexOf("\"", attValueIndexBegin);
		return str.substring(attValueIndexBegin, attValueIndexEnd);
	}
	
	/*Function that replace the shortcode by the string given in the arguments*/
	private static String replaceShortcode(String str, String shortcode, String hdocCode){
		StringBuilder strBuilder = new StringBuilder(str);
		int begin = strBuilder.indexOf("["+shortcode);
		int end = strBuilder.indexOf("[/"+shortcode+"]") + ("[/"+shortcode+"]").length();
		strBuilder.replace(begin,end, hdocCode);
		return strBuilder.toString();
	}
}
