<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:excerpt="http://wordpress.org/export/1.2/excerpt/"
    xmlns:content="http://purl.org/rss/1.0/modules/content/"
    xmlns:wp="http://wordpress.org/export/1.2/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:xalan="http://xml.apache.org/xslt"
    xmlns="http://www.utc.fr/ics/hdoc/xhtml"
    exclude-result-prefixes="wp dc content excerpt xs xalan">
 
    <xsl:variable name="rootChannel" select="/rss/channel"/>
    
    <xsl:output method="xml" indent="yes" omit-xml-declaration="no" xalan:indent-amount="4"/>
    <!-- matching the root element -->
    <xsl:template match="rss">
        <!-- Adding the RNGSchema -->
        <xsl:processing-instruction name="oxygen">RNGSchema="http://scenari.utc.fr/hdoc/schemas/xhtml/hdoc1-xhtml.rng" type="xml"</xsl:processing-instruction>
        <!-- Applying the templates -->
        <xsl:apply-templates/>
    </xsl:template>
    
    <!-- With one WordPress multi-site installation we can have many websites.
        channel is the element that contains all the information about 
        each Website. In this case we have used WordPress Mono-site so we
        will deal only with one channel element. -->
    <xsl:template match="channel">        
        <html>
            <!-- head conversion -->
            <head>
                <!-- The head title is the global title of the WordPress website -->
                <title><xsl:value-of select="title" /></title>
                <meta charset="utf-8"><xsl:text/></meta>
                <meta generator="HdocConverter/Wordpress"><xsl:text/></meta>
                <!-- the meta description is the global description of the WordPress website -->
                <meta name="description">
                    <xsl:attribute name="content"><xsl:value-of select="description"/></xsl:attribute>
                    <xsl:text/>
                </meta>
                <!-- For the meta author tag, we choose to put all the authors separated by '-'. -->
                <meta name="author">
                    <xsl:attribute name="content">
                        <xsl:call-template name="authorsList" />
                    </xsl:attribute>
                    <xsl:text/>
                </meta>        
            </head>
            
            <!-- Body conversion -->
            <body>
                <xsl:apply-templates />
            </body>
        </html>
    </xsl:template>
    
    <!-- WordPress Has 2 main publications format: post and page -->
    <!-- NOTE: Below we will use the term "publication" to refer to both the pages and the posts format -->
    
    <!-- matching the publications -->
    <xsl:template match="item[wp:post_type = 'post' or wp:post_type = 'page']">
       <section>
           <!-- Publication header --> 
           <!-- A post or a page in WordPress has always an author so it will have a header in the hdoc -->
            <header>
                <h1><xsl:value-of select="title"/></h1>
                <!-- publication author -->
                <xsl:apply-templates select="dc:creator"></xsl:apply-templates>
                
                <!-- publication date -->
                <div data-hdoc-type="date">
                   <xsl:value-of select="pubDate"/>               
                </div> 
            </header>
           
          <!-- If the publication has a featured image we put this image just after the header and before the content -->
           <xsl:if test="wp:postmeta/wp:meta_key = '_thumbnail_id'">
               <xsl:apply-templates select="wp:postmeta[wp:meta_key = '_thumbnail_id']"></xsl:apply-templates>
           </xsl:if> 

           <!--<xsl:value-of select="content:encoded" disable-output-escaping="yes"/> -->
               <xsl:call-template name="content"/>
           
           
           <!-- publication footer -->
           <!-- Good to know: pages does not have tags nor categories so only the posts are concerned--> 
           <footer> 
             <!-- transform the tags if they exist -->
               <xsl:if test="category[@domain = 'post_tag']">
                   <div data-hdoc-type="tags">
                       <xsl:apply-templates select="category[@domain = 'post_tag']"/>
                   </div>
               </xsl:if>
               <!-- transform the categories if they exist -->
               <xsl:if test="category[@domain = 'category']">
                   <div data-hdoc-type="categories">
                       <xsl:apply-templates select="category[@domain = 'category']"/>
                   </div>   
               </xsl:if>
           </footer>
        </section>
    </xsl:template>
    
    <!-- Publication authors -->
    <xsl:template match="item[wp:post_type = 'post' or wp:post_type = 'page']/dc:creator">
        <div data-hdoc-type="author">
            <xsl:value-of select="."/>
        </div>
    </xsl:template>
    
    <!-- Publication's categories -->
    <xsl:template match="category[@domain = 'category']">
        <span><xsl:value-of select="."/></span>          
    </xsl:template>
    
    <!-- Publication's tags -->
    <xsl:template match="category[@domain = 'post_tag']">
        <span><xsl:value-of select="."/></span>          
    </xsl:template>
    
    <!-- Publication's featured image -->
    <xsl:template match="wp:postmeta[wp:meta_key = '_thumbnail_id']">
         <div>
             <img src="{//item[wp:post_id = current()/wp:meta_value]/guid}" 
                 alt="{//item[wp:post_id = current()/wp:meta_value]/wp:postmeta[wp:meta_key ='_wp_attachment_image_alt']/wp:meta_value}"/>
         </div>
    </xsl:template>
    
    <!--List of authors that is put in the meta author tag element in the head-->
    <xsl:template name="authorsList">
        <!-- In wordpress if an author didn't post anything he is not exported in the xml
        so we are sure that all the authors exported in the xml have written something-->
        <xsl:for-each select="$rootChannel/wp:author">
            <xsl:value-of select="wp:author_login"></xsl:value-of>
            <xsl:if test="position() != last()">
               <xsl:text> - </xsl:text>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    
    <xsl:template name="content">
        <div>
            <xsl:apply-templates select="//audio|//video"/>
        </div>
    </xsl:template>
    
    <xsl:template match="//audio|//video">
        <xsl:copy-of select="." copy-namespaces="no"></xsl:copy-of>
    </xsl:template>
   <!-- overriding default rules --> 
    <xsl:template match="text()|@*"> </xsl:template>
    
    
</xsl:stylesheet>